@@ -4,6 +4,8 @@ from ai21.api_resources import supported_resources
 
 
 def construct_ai21_object(obj):
+    if not isinstance(obj, dict):
+        return obj
     class_type = AI21Object
     type_key = obj.get("type", None)
     if type_key is not None:
